==> ejc-mdm-impl-3.0.0-20220414.124012-52-sources.jar: com/ejianc/foundation/mdm/bean/DataSubscribeEntity.java <==
package com.ejianc.foundation.mdm.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 数据订阅
 * 
 * @author guoming
 *
 */
@TableName("ejc_mdm_datasubscribe")
public class DataSubscribeEntity extends BaseEntity {

	private static final long serialVersionUID = 1L;

	/**
	 * 主数据模型ID
	 */
	@TableField(value = "data_model_id")
	private Long dataModelId;
	/**
	 * 数据订阅编码
	 */
	@TableField(value = "subscribe_code")
	private String subscribeCode;
	/**
	 * 数据订阅名称
	 */
	@TableField(value = "subscribe_name")
	private String subscribeName;
	/**
	 * 集成系统ID
	 */
	@TableField(value = "third_system_id")
	private Long thirdSystemId;
	/**
	 * 查询条件
	 */
	@TableField(value = "query_condition")
	private String queryCondition;

	public Long getDataModelId() {
		return dataModelId;
	}

	public void setDataModelId(Long dataModelId) {
		this.dataModelId = dataModelId;
	}

	public String getSubscribeCode() {
		return subscribeCode;
	}

	public void setSubscribeCode(String subscribeCode) {
		this.subscribeCode = subscribeCode;
	}

	public String getSubscribeName() {
		return subscribeName;
	}

	public void setSubscribeName(String subscribeName) {
		this.subscribeName = subscribeName;
	}

	public Long getThirdSystemId() {
		return thirdSystemId;
	}

	public void setThirdSystemId(Long thirdSystemId) {
		this.thirdSystemId = thirdSystemId;
	}

	public String getQueryCondition() {
		return queryCondition;
	}

	public void setQueryCondition(String queryCondition) {
		this.queryCondition = queryCondition;
	}

}

==> ejc-mdm-impl-3.0.0-20251212.060902-198-sources.jar: com/ejianc/foundation/mdm/bean/DataSubscribeEntity.java <==
package com.ejianc.foundation.mdm.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 数据订阅
 * 
 * @author guoming
 *
 */
@TableName("ejc_mdm_datasubscribe")
public class DataSubscribeEntity extends BaseEntity {

	private static final long serialVersionUID = 1L;

	/**
	 * 主数据模型ID
	 */
	@TableField(value = "data_model_id")
	private Long dataModelId;

	/**
	 * 主数据模型名称
	 */
	@TableField(value = "data_model_name")
	private String dataModelName;
	/**
	 * 数据订阅编码
	 */
	@TableField(value = "subscribe_code")
	private String subscribeCode;
	/**
	 * 数据订阅名称
	 */
	@TableField(value = "subscribe_name")
	private String subscribeName;
	/**
	 * 集成系统ID
	 */
	@TableField(value = "third_system_id")
	private Long thirdSystemId;

	/**
	 * 集成系统名称
	 */
	@TableField(value = "third_system_name")
	private String thirdSystemName;

	/**
	 * 启停标识 1启用 0停用
	 */
	@TableField(value = "enable_flag")
	private Integer enableFlag;

	public Long getDataModelId() {
		return dataModelId;
	}

	public void setDataModelId(Long dataModelId) {
		this.dataModelId = dataModelId;
	}

	public String getDataModelName() {
		return dataModelName;
	}

	public void setDataModelName(String dataModelName) {
		this.dataModelName = dataModelName;
	}

	public String getSubscribeCode() {
		return subscribeCode;
	}

	public void setSubscribeCode(String subscribeCode) {
		this.subscribeCode = subscribeCode;
	}

	public String getSubscribeName() {
		return subscribeName;
	}

	public void setSubscribeName(String subscribeName) {
		this.subscribeName = subscribeName;
	}

	public Long getThirdSystemId() {
		return thirdSystemId;
	}

	public void setThirdSystemId(Long thirdSystemId) {
		this.thirdSystemId = thirdSystemId;
	}

	public String getThirdSystemName() {
		return thirdSystemName;
	}

	public void setThirdSystemName(String thirdSystemName) {
		this.thirdSystemName = thirdSystemName;
	}

	public Integer getEnableFlag() {
		return enableFlag;
	}

	public void setEnableFlag(Integer enableFlag) {
		this.enableFlag = enableFlag;
	}

}
